diff -NauBwr -x .libs -x '*.o' -x '*o' -x '*a' -x Makefile -x rquota.h -x rquota_xdr.c -x quota-fs.h dovecot-1.1.1-orig/src/plugins/quota/quota-fs.c dovecot-1.1.1/src/plugins/quota/quota-fs.c
--- dovecot-1.1.1-orig/src/plugins/quota/quota-fs.c	2008-06-12 22:48:38.000000000 +0200
+++ dovecot-1.1.1/src/plugins/quota/quota-fs.c	2008-07-12 17:07:44.000000000 +0200
@@ -29,6 +29,10 @@
 #  define RQUOTA_GETQUOTA_TIMEOUT_SECS 10
 #endif
 
+#ifdef DQBSIZE
+#  define DEV_BSIZE DQBSIZE
+#endif
+
 #ifndef DEV_BSIZE
 #  define DEV_BSIZE 512
 #endif
@@ -585,6 +589,34 @@
 }
 
 static int
+fs_quota_root_match_box(struct quota_root *_root, struct mailbox *box)
+{
+	struct fs_quota_root *root = (struct fs_quota_root *)_root;
+	struct stat mst, rst;
+	const char *mailbox_path;
+	bool is_file;
+	int does_match;
+
+	if (root == NULL || box == NULL)
+		return 0;
+
+	mailbox_path = mail_storage_get_mailbox_path(
+					mailbox_get_storage(box),
+					mailbox_get_name(box),
+					&is_file);
+
+	does_match = (stat(mailbox_path,&mst) >= 0 &&
+					stat(root->storage_mount_path,&rst) >= 0 &&
+					CMP_DEV_T(mst.st_dev,rst.st_dev));
+
+	if (getenv("DEBUG") != NULL)
+	 	i_info("storage=%s box=%s match=%i", mailbox_path,
+	 				root->storage_mount_path, does_match);
+
+ 	return does_match;
+}
+
+static int
 fs_quota_get_resource(struct quota_root *_root, const char *name,
 		      uint64_t *value_r)
 {
@@ -648,7 +680,9 @@
 
 		fs_quota_root_get_resources,
 		fs_quota_get_resource,
-		fs_quota_update
+		fs_quota_update,
+
+		fs_quota_root_match_box
 	}
 };
 
diff -NauBwr -x .libs -x '*.o' -x '*o' -x '*a' -x Makefile -x rquota.h -x rquota_xdr.c -x quota-fs.h dovecot-1.1.1-orig/src/plugins/quota/quota-private.h dovecot-1.1.1/src/plugins/quota/quota-private.h
--- dovecot-1.1.1-orig/src/plugins/quota/quota-private.h	2008-06-12 08:45:10.000000000 +0200
+++ dovecot-1.1.1/src/plugins/quota/quota-private.h	2008-07-08 13:55:33.000000000 +0200
@@ -54,6 +54,10 @@
 
 	int (*update)(struct quota_root *root, 
 		      struct quota_transaction_context *ctx);
+
+	int (*root_match_box)(struct quota_root *root,
+			  struct mailbox *box);
+
 };
 
 struct quota_backend {
diff -NauBwr -x .libs -x '*.o' -x '*o' -x '*a' -x Makefile -x rquota.h -x rquota_xdr.c -x quota-fs.h dovecot-1.1.1-orig/src/plugins/quota/quota.c dovecot-1.1.1/src/plugins/quota/quota.c
--- dovecot-1.1.1-orig/src/plugins/quota/quota.c	2008-06-12 12:16:39.000000000 +0200
+++ dovecot-1.1.1/src/plugins/quota/quota.c	2008-07-09 19:47:12.000000000 +0200
@@ -542,6 +542,11 @@
 		return NULL;
 
 	for (; iter->i < count; iter->i++) {
+
+		if (roots[iter->i]->backend.v.root_match_box != NULL && 
+			roots[iter->i]->backend.v.root_match_box(roots[iter->i], iter->box) == 0)
+			continue;
+
 		ret = quota_get_resource(roots[iter->i], "",
 					 QUOTA_NAME_STORAGE_KILOBYTES,
 					 &value, &limit);
@@ -668,6 +674,10 @@
 			continue;
 		}
 
+		if (roots[i]->backend.v.root_match_box != NULL && 
+			roots[i]->backend.v.root_match_box(roots[i], ctx->box) == 0)
+			continue;
+
 		ret = quota_get_resource(roots[i], mailbox_name,
 					 QUOTA_NAME_STORAGE_BYTES,
 					 &current, &limit);
@@ -760,6 +770,11 @@
 		mailbox_name = mailbox_get_name(ctx->box);
 		roots = array_get(&ctx->quota->roots, &count);
 		for (i = 0; i < count; i++) {
+
+			if (roots[i]->backend.v.root_match_box != NULL && 
+				roots[i]->backend.v.root_match_box(roots[i], ctx->box) == 0)
+				continue;
+
 			rule = quota_root_rule_find(roots[i], mailbox_name);
 			if (rule != NULL && rule->ignore) {
 				/* mailbox not included in quota */
@@ -833,6 +848,10 @@
 	for (i = 0; i < count; i++) {
 		uint64_t bytes_limit, count_limit;
 
+		if (roots[i]->backend.v.root_match_box != NULL && 
+			roots[i]->backend.v.root_match_box(roots[i], ctx->box) == 0)
+			continue;
+
 		if (!quota_root_get_rule_limits(roots[i],
 						mailbox_get_name(ctx->box),
 						&bytes_limit, &count_limit))
